---
name: Bug report
about: Create a report to help us improve. **❗ IMPORTANT:** If you have difficulties creating a dataset from any source, please provide us with a sample data file or a URL to the source data.
title: ''
labels: ''
assignees: ''

---
**Describe the bug**
A clear and concise description of what the bug is.

** Version number **
I am using the following versions/branch/sha1 of the anemoi packages
(alternatively the output of `pip freeze`)

**To Reproduce**
Steps to reproduce the behavior:
1. Go to '...'
2. Run this '....'
3. See error

**URL to sample input data**
Provide a URL to a sample input data, or attach a file to that report if it is small enough.

**Expected behavior**
A clear and concise description of what you expected to happen.

**Screenshots**
If applicable, add screenshots to help explain your problem.

**Additional context**
Add any other context about the problem here.
